summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorKarl Mikaelsson <derfian@cendio.se>2017-12-08 11:26:31 +0100
committerKarl Mikaelsson <derfian@cendio.se>2018-01-25 16:47:17 +0100
commit2f6cd4df7e55b68c9c846a6db1b72bfcef3017b1 (patch)
tree3241ffbe2b029c9ca0dbf057b892926ace5ddfcf
parentca5c0adefd348f39f6ce2fb678fbf5f18ea3ff74 (diff)
downloadrdesktop-2f6cd4df7e55b68c9c846a6db1b72bfcef3017b1.zip
Improve handling/code of Set Error Info PDU
Renamed to function to match the PDU it was processing. Removed the function from proto.h and made it static - there's nothing calling this from outside of rdp.c. Fixed the logging output to output the error code instead of the pointer value.
-rw-r--r--proto.h1
-rw-r--r--rdp.c10
2 files changed, 5 insertions, 6 deletions
diff --git a/proto.h b/proto.h
index 7d54e93..f346646 100644
--- a/proto.h
+++ b/proto.h
@@ -158,7 +158,6 @@ void process_system_pointer_pdu(STREAM s);
void set_system_pointer(uint32 ptr);
void process_bitmap_updates(STREAM s);
void process_palette(STREAM s);
-void process_disconnect_pdu(STREAM s, uint32 * ext_disc_reason);
void rdp_main_loop(RD_BOOL * deactivated, uint32 * ext_disc_reason);
RD_BOOL rdp_loop(RD_BOOL * deactivated, uint32 * ext_disc_reason);
RD_BOOL rdp_connect(char *server, uint32 flags, char *domain, char *password, char *command,
diff --git a/rdp.c b/rdp.c
index 4102a9e..7b0fded 100644
--- a/rdp.c
+++ b/rdp.c
@@ -1512,13 +1512,13 @@ process_pdu_logon(STREAM s)
}
-/* Process a disconnect PDU */
-void
-process_disconnect_pdu(STREAM s, uint32 * ext_disc_reason)
+/* Process a Set Error Info PDU */
+static void
+process_ts_set_error_info_pdu(STREAM s, uint32 * ext_disc_reason)
{
in_uint32_le(s, *ext_disc_reason);
- logger(Protocol, Debug, "process_disconnect_pdu(), reason = %d", ext_disc_reason);
+ logger(Protocol, Debug, "process_ts_set_error_info_pdu(), error info = %d", *ext_disc_reason);
}
/* Process data PDU */
@@ -1594,7 +1594,7 @@ process_data_pdu(STREAM s, uint32 * ext_disc_reason)
break;
case RDP_DATA_PDU_DISCONNECT:
- process_disconnect_pdu(s, ext_disc_reason);
+ process_ts_set_error_info_pdu(s, ext_disc_reason);
/* We used to return true and disconnect immediately here, but
* Windows Vista sends a disconnect PDU with reason 0 when